aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIOhannes m zmölnig <zmoelnig@users.sourceforge.net>2010-08-15 13:47:56 +0000
committerIOhannes m zmölnig <zmoelnig@users.sourceforge.net>2010-08-15 13:47:56 +0000
commitf2e071aaca9f3fa07588ff5f397d1d8a52da5270 (patch)
tree738c37651ac241002e90d13dc1fffe0c6d7d70f2
parent31db607d80798f2a4267b78169218feff0bfc7c7 (diff)
added copyright splash
svn path=/trunk/externals/hardware/wiimote/; revision=13796
-rw-r--r--wiimote.c8
1 files changed, 7 insertions, 1 deletions
diff --git a/wiimote.c b/wiimote.c
index 80eacdb..e6391a1 100644
--- a/wiimote.c
+++ b/wiimote.c
@@ -1,6 +1,6 @@
// ===================================================================
// Wiimote external for Puredata
// Written by Mike Wozniewki (Feb 2007), www.mikewoz.com
//
// Requires the CWiid library (version 0.6.00) by L. Donnie Smith
//
@@ -1139,4 +1139,10 @@ void wiimote_setup(void)
/* set things on the wiimote */
class_addmethod(wiimote_class, (t_method) wiimote_setRumble, gensym("setRumble"), A_FLOAT, 0);
class_addmethod(wiimote_class, (t_method) wiimote_setLED, gensym("setLED"), A_FLOAT, 0);
+
+ post("[wiimote]: reading data from the Wii remote controller");
+ post(" (c) 2007 Mike Wozniewski");
+ post(" (c) 2008-2009 Florian Krebs");
+ post(" (c) 2009-2010 IOhannes m zmoelnig");
+ post(" version 0.3 published under the GNU General Public License");
}
@@ -1,6 +1,6 @@
// ===================================================================
// Wiimote external for Puredata
-// Written by Mike Wozniewki (Feb 2007), www.mikewoz.com
+// Written by Mike Wozniewski (Feb 2007), www.mikewoz.com
//
// Requires the CWiid library (version 0.6.00) by L. Donnie Smith